@@ -255,9 +255,9 @@ elseif (hasRequest('action') && getRequest('action') == 'host.massupdate' && has
 		$hosts = API::Host()->get([
 			'output' => ['hostid'],
 			'hostids' => $hostIds,
+			'selectInventory' => ['inventory_mode'],
 			'filter' => ['flags' => [ZBX_FLAG_DISCOVERY_NORMAL, ZBX_FLAG_DISCOVERY_CREATED]]
 		]);
-		$hosts = ['hosts' => $hosts];
 
 		$properties = [
 			'proxy_hostid', 'ipmi_authtype', 'ipmi_privilege', 'ipmi_username', 'ipmi_password', 'description'
@@ -274,25 +274,25 @@ elseif (hasRequest('action') && getRequest('action') == 'host.massupdate' && has
 			$newValues['status'] = getRequest('status', HOST_STATUS_NOT_MONITORED);
 		}
 
-		if (isset($visible['inventory_mode'])) {
-			$newValues['inventory_mode'] = getRequest('inventory_mode', HOST_INVENTORY_DISABLED);
-			$newValues['inventory'] = ($newValues['inventory_mode'] == HOST_INVENTORY_DISABLED)
-				? []
-				: getRequest('host_inventory', []);
-		}
-
 		if (array_key_exists('encryption', $visible)) {
 			$newValues['tls_connect'] = getRequest('tls_connect', HOST_ENCRYPTION_NONE);
 			$newValues['tls_accept'] = getRequest('tls_accept', HOST_ENCRYPTION_NONE);
-			$newValues['tls_issuer'] = getRequest('tls_issuer', '');
-			$newValues['tls_subject'] = getRequest('tls_subject', '');
-			$newValues['tls_psk_identity'] = getRequest('tls_psk_identity', '');
-			$newValues['tls_psk'] = getRequest('tls_psk', '');
+
+			if ($newValues['tls_connect'] == HOST_ENCRYPTION_PSK || ($newValues['tls_accept'] & HOST_ENCRYPTION_PSK)) {
+				$newValues['tls_psk_identity'] = getRequest('tls_psk_identity', '');
+				$newValues['tls_psk'] = getRequest('tls_psk', '');
+			}
+
+			if ($newValues['tls_connect'] == HOST_ENCRYPTION_CERTIFICATE
+					|| ($newValues['tls_accept'] & HOST_ENCRYPTION_CERTIFICATE)) {
+				$newValues['tls_issuer'] = getRequest('tls_issuer', '');
+				$newValues['tls_subject'] = getRequest('tls_subject', '');
+			}
 		}
 
-		$templateIds = [];
+		$templateids = [];
 		if (isset($visible['templates'])) {
-			$templateIds = $_REQUEST['templates'];
+			$templateids = $_REQUEST['templates'];
 		}
 
 		// add new or existing host groups
@@ -334,14 +334,14 @@ elseif (hasRequest('action') && getRequest('action') == 'host.massupdate' && has
 			}
 
 			if (isset($replaceHostGroupsIds)) {
-				$hosts['groups'] = API::HostGroup()->get([
+				$newValues['groups'] = API::HostGroup()->get([
 					'groupids' => $replaceHostGroupsIds,
 					'editable' => true,
 					'output' => ['groupid']
 				]);
 			}
 			else {
-				$hosts['groups'] = [];
+				$newValues['groups'] = [];
 			}
 		}
 		elseif ($newHostGroupIds) {
@@ -360,22 +360,48 @@ elseif (hasRequest('action') && getRequest('action') == 'host.massupdate' && has
 				]);
 
 				$hostTemplateIds = zbx_objectValues($hostTemplates, 'templateid');
-				$templatesToDelete = array_diff($hostTemplateIds, $templateIds);
+				$templatesToDelete = array_diff($hostTemplateIds, $templateids);
 
-				$hosts['templates_clear'] = zbx_toObject($templatesToDelete, 'templateid');
+				$newValues['templates_clear'] = zbx_toObject($templatesToDelete, 'templateid');
 			}
 
-			$hosts['templates'] = $templateIds;
+			$hosts['templates'] = $templateids;
 		}
 
-		$result = API::Host()->massUpdate(array_merge($hosts, $newValues));
+		$host_inventory = array_intersect_key(getRequest('host_inventory', []), $visible);
+
+		if (hasRequest('inventory_mode') && array_key_exists('inventory_mode', $visible)) {
+			$newValues['inventory_mode'] = getRequest('inventory_mode', HOST_INVENTORY_DISABLED);
+
+			if ($newValues['inventory_mode'] == HOST_INVENTORY_DISABLED) {
+				$host_inventory = [];
+			}
+		}
+
+		foreach ($hosts as &$host) {
+			if (array_key_exists('inventory_mode', $newValues)) {
+				$host['inventory'] = $host_inventory;
+			}
+			elseif (array_key_exists('inventory_mode', $host['inventory'])
+					&& $host['inventory']['inventory_mode'] != HOST_INVENTORY_DISABLED) {
+				$host['inventory'] = $host_inventory;
+			}
+			else {
+				$host['inventory'] = [];
+			}
+			$host = array_merge($host, $newValues);
+		}
+		unset($host);
+
+		$result = (bool) API::Host()->update($hosts);
+
 		if ($result === false) {
 			throw new Exception();
 		}
 
 		$add = [];
-		if ($templateIds && isset($visible['templates'])) {
-			$add['templates'] = $templateIds;
+		if ($templateids && isset($visible['templates'])) {
+			$add['templates'] = $templateids;
 		}
 
 		// add new host groups
@@ -384,7 +410,8 @@ elseif (hasRequest('action') && getRequest('action') == 'host.massupdate' && has
 		}
 
 		if ($add) {
-			$add['hosts'] = $hosts['hosts'];
+			$hostsids = zbx_objectValues($hosts, 'hostid');
+			$add['hosts'] = zbx_toObject($hostsids, 'hostid');
 
 			$result = API::Host()->massAdd($add);
 
@@ -398,7 +425,7 @@ elseif (hasRequest('action') && getRequest('action') == 'host.massupdate' && has
 		uncheckTableRows();
 		show_message(_('Hosts updated'));
 
-		unset($_REQUEST['massupdate'], $_REQUEST['form'], $_REQUEST['hosts']);
+		unset($_REQUEST['masssave'], $_REQUEST['form'], $_REQUEST['hosts']);
 	}
 	catch (Exception $e) {
 		DBend(false);
@@ -510,10 +537,6 @@ elseif (hasRequest('add') || hasRequest('update')) {
 				'ipmi_password' => getRequest('ipmi_password'),
 				'tls_connect' => getRequest('tls_connect', HOST_ENCRYPTION_NONE),
 				'tls_accept' => getRequest('tls_accept', HOST_ENCRYPTION_NONE),
-				'tls_issuer' => getRequest('tls_issuer'),
-				'tls_subject' => getRequest('tls_subject'),
-				'tls_psk_identity' => getRequest('tls_psk_identity'),
-				'tls_psk' => getRequest('tls_psk'),
 				'groups' => $groups,
 				'templates' => $templates,
 				'interfaces' => $interfaces,
@@ -524,6 +547,17 @@ elseif (hasRequest('add') || hasRequest('update')) {
 					: getRequest('host_inventory', [])
 			];
 
+			if ($host['tls_connect'] == HOST_ENCRYPTION_PSK || ($host['tls_accept'] & HOST_ENCRYPTION_PSK)) {
+				$host['tls_psk_identity'] = getRequest('tls_psk_identity', '');
+				$host['tls_psk'] = getRequest('tls_psk', '');
+			}
+
+			if ($host['tls_connect'] == HOST_ENCRYPTION_CERTIFICATE
+					|| ($host['tls_accept'] & HOST_ENCRYPTION_CERTIFICATE)) {
+				$host['tls_issuer'] = getRequest('tls_issuer', '');
+				$host['tls_subject'] = getRequest('tls_subject', '');
+			}
+
 			if (!$create) {
 				$host['templates_clear'] = zbx_toObject(getRequest('clear_templates', []), 'templateid');
 			}
@@ -725,7 +759,7 @@ $_REQUEST['hostid'] = getRequest('hostid', 0);
 
 $config = select_config();
 
-if (hasRequest('action') && getRequest('action') === 'host.massupdateform' && hasRequest('hosts')) {
+if ((getRequest('action') === 'host.massupdateform' || hasRequest('masssave')) && hasRequest('hosts')) {
 	$data = [
 		'hosts' => getRequest('hosts'),
 		'visible' => getRequest('visible', []),
@@ -1029,6 +1063,13 @@ elseif (hasRequest('form')) {
 			'templateids' => $data['templates']
 		]);
 		CArrayHelper::sort($data['linked_templates'], ['name']);
+
+		$data['writable_templates'] = API::Template()->get([
+			'output' => ['templateid'],
+			'templateids' => $data['templates'],
+			'editable' => true,
+			'preservekeys' => true
+		]);
 	}
 
 	$hostView = new CView('configuration.host.edit', $data);
@@ -1083,26 +1124,50 @@ else {
 	order_result($hosts, $sortField, $sortOrder);
 
 	// selecting linked templates to templates linked to hosts
-	$templateIds = [];
+	$templateids = [];
+
 	foreach ($hosts as $host) {
-		$templateIds = array_merge($templateIds, zbx_objectValues($host['parentTemplates'], 'templateid'));
+		$templateids = array_merge($templateids, zbx_objectValues($host['parentTemplates'], 'templateid'));
 	}
-	$templateIds = array_unique($templateIds);
+
+	$templateids = array_keys(array_flip($templateids));
 
 	$templates = API::Template()->get([
 		'output' => ['templateid', 'name'],
-		'templateids' => $templateIds,
+		'templateids' => $templateids,
 		'selectParentTemplates' => ['hostid', 'name'],
 		'preservekeys' => true
 	]);
 
+	// selecting writable templates IDs
+	$writable_templates = [];
+	if ($templateids) {
+		foreach ($templates as $template) {
+			$templateids = array_merge($templateids, zbx_objectValues($template['parentTemplates'], 'templateid'));
+		}
+
+		$writable_templates = API::Template()->get([
+			'output' => ['templateid'],
+			'templateids' => array_keys(array_flip($templateids)),
+			'editable' => true,
+			'preservekeys' => true
+		]);
+	}
+
 	// get proxy host IDs that that are not 0
 	$proxyHostIds = [];
-	foreach ($hosts as $host) {
+	foreach ($hosts as &$host) {
+		// Sort interfaces to be listed starting with one selected as 'main'.
+		CArrayHelper::sort($host['interfaces'], [
+			['field' => 'main', 'order' => ZBX_SORT_DOWN]
+		]);
+
 		if ($host['proxy_hostid']) {
 			$proxyHostIds[$host['proxy_hostid']] = $host['proxy_hostid'];
 		}
 	}
+	unset($host);
+
 	$proxies = [];
 	if ($proxyHostIds) {
 		$proxies = API::Proxy()->get([
@@ -1122,6 +1187,7 @@ else {
 		'groupId' => $pageFilter->groupid,
 		'config' => $config,
 		'templates' => $templates,
+		'writable_templates' => $writable_templates,
 		'proxies' => $proxies
 	];
 
